@@ -1,6 +1,6 @@
 /* Jeroen Ooms (2018)
  * Bindings to vectorized image manipulations.
- * See API: https://www.imagemagick.org/Magick++/STL.html
+ * See API: https://imagemagick.org/Magick++/STL.html
  */
 
 #include "magick_types.h"
@@ -117,6 +117,15 @@ XPtrImage magick_image_background( XPtrImage input, const char * color){
   return output;
 }
 
+// [[Rcpp::export]]
+XPtrImage magick_image_virtual_pixel( XPtrImage input, const char * method ) {
+  XPtrImage output = copy(input);
+  for(size_t i = 0; i < output->size(); i++) {
+    output->at(i).virtualPixelMethod(VirtualPixelValue(method));
+  }
+  return output;
+}
+
 // [[Rcpp::export]]
 XPtrImage magick_image_lat( XPtrImage input, const char * geomstr){
   Magick::Geometry geom = Geom(geomstr);
@@ -184,3 +193,11 @@ XPtrImage magick_image_level( XPtrImage input, double black_pct, double white_pc
   }
   return output;
 }
+
+Magick::VirtualPixelMethod VirtualPixelValue(const char * str){
+  ssize_t val = MagickCore::ParseCommandOption(
+    MagickCore::MagickVirtualPixelOptions, Magick::MagickFalse, str);
+  if(val < 0)
+    throw std::runtime_error(std::string("Invalid VirtualPixelMethod value: ") + str);
+  return (Magick::VirtualPixelMethod) val;
+}
